import { recombine } from "./util/recombine.js";
export function ResponseFormat(name, ty) {
    return ResponseFormat_(name, ty);
}
function ResponseFormat_(name, ty, description) {
    return Object.assign((template, ...quasis) => ResponseFormat_(name, ty, description ? `${description} ${recombine(template, quasis)}` : undefined), {
        type: "json_schema",
        json_schema: {
            name,
            description,
            schema: ty.schema(),
            strict: true,
        },
        into: (completion) => {
            return ty[""].transform(JSON.parse(ResponseFormat.unwrapFirstChoice(completion)));
        },
        toJSON() {
            const { type, json_schema } = this;
            return { type, json_schema };
        },
    });
}
(function (ResponseFormat) {
    function unwrapFirstChoice(completion) {
        const { choices: [firstChoice] } = completion;
        if (!firstChoice) {
            throw new ResponseFormatUnwrapError("No choices contained within the completion response.");
        }
        return unwrapChoice(firstChoice);
    }
    ResponseFormat.unwrapFirstChoice = unwrapFirstChoice;
    function unwrapChoices(completions) {
        return completions.choices.map(unwrapChoice);
    }
    ResponseFormat.unwrapChoices = unwrapChoices;
    function unwrapChoice(choice) {
        const { finish_reason, message } = choice;
        if (finish_reason !== "stop") {
            throw new ResponseFormatUnwrapError(`Completion responded with "${finish_reason}" as finish reason; ${message}`);
        }
        const { content, refusal } = message;
        if (refusal) {
            throw new ResponseFormatUnwrapError(`Openai refused to fulfill completion request; ${refusal}`);
        }
        if (!content) {
            throw new ResponseFormatUnwrapError("First response choice contained no content.");
        }
        return content;
    }
})(ResponseFormat || (ResponseFormat = {}));
export class ResponseFormatUnwrapError extends Error {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: "UnwrapResponseError"
        });
    }
}
//# sourceMappingURL=ResponseFormat.js.map